unit ufrmOutput;

interface

{$ifdef LINUX}

uses
  SysUtils, Types, Classes, Variants, QGraphics,
  QControls, QForms, QDialogs, QExtCtrls,
  ufrmDraw, ufrmApp;

{$endif}

{$ifdef WIN32}

uses
  Windows, Messages, SysUtils, Types, Classes,
  Graphics, Controls, Forms, Dialogs, ExtCtrls,
  ufrmDraw, ufrmApp;

{$endif}

type
  TfrmOutput = class(TForm)
    Image1: TImage;
    procedure FormClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormMouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure FormMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure FormMouseUp(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure FormPaint(Sender: TObject);
  private
    { Private declarations }
    frmDraw: TfrmDraw;
    frmApp: TfrmApp;
    FCurPos: PPoint;
  public
    { Public declarations }
  end;

var
  frmOutput: TfrmOutput;

implementation

{$R *.xfm}

procedure TfrmOutput.FormClick(Sender: TObject);
var
  tmpCanvas: TCanvas;
  tmpRect: TRect;
begin
  if (Sender is TCustomForm) or
     (Sender is TImage) then
  begin
    if (Sender is TCustomForm) then
    begin
      tmpCanvas := (Sender as TCustomForm).Canvas;
      tmpRect.Left := 0;
      tmpRect.Top := 0;
      tmpRect.Right := Self.ClientWidth;
      tmpRect.Bottom := Self.ClientHeight;
    end
    else
    begin
      tmpCanvas := (Sender as TImage).Canvas;
      tmpRect.Left := 0;
      tmpRect.Top := 0;
      tmpRect.Right := TImage(Sender).ClientWidth;
      tmpRect.Bottom := TImage(Sender).ClientHeight;
    end;
    if (frmDraw.TargetCanvas <> tmpCanvas) then
    begin
      frmDraw.TargetCanvas := tmpCanvas;
      frmDraw.ClearRect := tmpRect;
      frmApp.TargetCanvas := tmpCanvas;
      if Sender = Self then
      begin
        frmDraw.StatusBar1.Panels[0].Text :=
          'Drawing on Form';
      end
      else
      begin
        frmDraw.StatusBar1.Panels[0].Text :=
          'Drawing on Image';
      end;
    end;
  end;
end;

procedure TfrmOutput.FormCreate(Sender: TObject);
begin
  // Create a point record to store the current
  // mouse position
  FCurPos := New(PPoint);
  FCurPos^.X := 0;
  FCurPos^.Y := 0;
  // Create the other forms
  frmDraw := TfrmDraw.Create(Self);
  frmDraw.Show;
  frmApp :=TfrmApp.Create(Self);
  frmApp.Show;
  // Set target canvas to form's
  Self.FormClick(Self);
  // Update drawing position
  Self.FormClick(Self);
end;

procedure TfrmOutput.FormDestroy(Sender: TObject);
begin
  frmDraw.Close;
  frmApp.Close;
  Dispose(FCurPos);
end;

procedure TfrmOutput.FormMouseMove(Sender: TObject; Shift: TShiftState; X,
  Y: Integer);
var
  tmpCanvas: TCanvas;
begin
  if (Sender is TCustomForm) or
     (Sender is TImage) then
  begin
    if (Sender is TCustomForm) then
      tmpCanvas := (Sender as TCustomForm).Canvas
    else
      tmpCanvas := (Sender as TImage).Canvas;
    if (frmDraw.TargetCanvas = tmpCanvas) then
    begin
      frmDraw.StatusBar1.Panels[1].Text :=
        'X: ' + IntToStr(X) + ', Y: ' + IntToStr(Y);
    end;
    // Set the current position, for use in OnClick
    FCurPos^.X := X;
    FCurPos^.Y := Y;
    frmDraw.MowseMove(Sender, Shift, X, Y);
  end;
end;

procedure TfrmOutput.FormMouseDown(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  frmDraw.MowseDown(Sender, Button, Shift, X, Y);
end;

procedure TfrmOutput.FormMouseUp(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  frmDraw.MowseUp(Sender, Button, Shift, X, Y);
end;

procedure TfrmOutput.FormPaint(Sender: TObject);
begin
  frmDraw.BringToFront;
  frmApp.BringToFront;
end;

end.
